@@ -166,12 +166,12 @@ trading_instruments <- function(connection, request, sec_detailed = FALSE, marke
         add_headers(.headers = c("X-Auth-Token" = connection@token)),
         user_agent(connection@agent)
         )
-  } else if (request %in% c('securities', 'by_type') && sec_detailed == F) {
+  } else if (request %in% c('securities', 'by_type') && sec_detailed == FALSE) {
     GET(url = glue(connection@base_url, "/rest/instruments/all"),
         add_headers(.headers = c("X-Auth-Token" = connection@token)),
         user_agent(connection@agent)
     )
-  } else if (request %in% c('securities', 'by_type') && sec_detailed == T) {
+  } else if (request %in% c('securities', 'by_type') && sec_detailed == TRUE) {
     GET(url = glue(connection@base_url, "/rest/instruments/details"),
         add_headers(.headers = c("X-Auth-Token" = connection@token)),
         user_agent(connection@agent)
@@ -208,17 +208,17 @@ trading_instruments <- function(connection, request, sec_detailed = FALSE, marke
       data <- data$segments %>%
         mutate_all(., unlist)
 
-    } else if (request %in% c('securities', 'by_type') && sec_detailed == F) {
+    } else if (request %in% c('securities', 'by_type') && sec_detailed == FALSE) {
 
       data <- data$instruments %>%
         jsonlite::flatten(recursive = F) %>%
         mutate_all(., unlist) %>%
         rename_all(., .funs = list(~gsub(pattern = ".+\\.", replacement = "", x = .)))
 
-    } else if (request %in% c('securities', 'by_type') && sec_detailed == T) {
+    } else if (request %in% c('securities', 'by_type') && sec_detailed == TRUE) {
 
       data <- data$instruments %>%
-        jsonlite::flatten(x = ., recursive = F) %>%
+        jsonlite::flatten(x = ., recursive = FALSE) %>%
         mutate(
           across(
             .cols = everything(),
@@ -261,36 +261,54 @@ trading_instruments <- function(connection, request, sec_detailed = FALSE, marke
       rename_all(., .funs = list(~gsub(pattern = "(^.)", replacement = "\\U\\1", x = ., perl = TRUE))) %>%
       as_tibble()
 
-    if (request %in% c('securities', 'by_type') && sec_detailed != F) {
-      suppressWarnings(data <- data %>%
-                         mutate(
-                           ProductType = factor(gsub(pattern = "(^.)(.+)", replacement = "\\1", x = Cficode), levels = c("E", "D", "C", "R", "O", "F", "T", "M"), labels = c("Equities", "Debt", "Collective Investment Vehicles", "Entitlements", "Options", "Futures", "Referencial Instruments", "Others")),
-                           Settlement = case_when(
-                             grepl(pattern = ".+ - (.+[hs|CI|D])$", x = Symbol) == TRUE ~ trimws(gsub(pattern = ".+ - (.+)$", replacement = "\\1", x = Symbol, ignore.case = T), which = "both"),
-                             TRUE ~ NA_character_
-                             ),
-                           OptionType = factor(gsub(pattern = "(^.{2})(.+)", replacement = "\\1", x = Cficode), levels = c("OC", "OP", "OM"), labels = c("Call", "Put", "Others")),
-                           Ticker = case_when(
-                             ProductType %in% c('Equities', 'Debt', 'Options') ~ trimws(gsub(pattern = "(MERV - XMEV - )(.+)( - .+)", replacement = "\\2", x = Symbol, ignore.case = T), which = "both"),
-                             ProductType %in% c('Entitlements') ~ trimws(gsub(pattern = "(MERV - XMEV - )(.+)", replacement = "\\2", x = Symbol, ignore.case = T), which = "both"),
-                             ProductType %in% c('Others') ~ trimws(gsub(pattern = "(.+)( - )(.+)$", replacement = "\\3", x = Symbol, ignore.case = T), which = "both"),
-                             TRUE ~ Symbol
-                             ),
-                           Underlying = case_when(
-                             ProductType %in% c('Options') && MarketSegmentId == 'MERV' ~ trimws(gsub(pattern = "(.{3})(.+)", replacement = "\\1", x = Ticker, ignore.case = T), which = "both"),
-                             ProductType %in% c('Options') && MarketSegmentId != 'MERV'~ trimws(gsub(pattern = "(.)?([[:alpha:]]{3})?([0-9]{2})?(/)?([0-9]{2})?( )([0-9]+)([p|c])$", replacement = "\\1", x = Symbol, ignore.case = T), which = "both"),
-                             ProductType %in% c('Futures') && grepl(pattern = "(Dispo)$", x = Ticker) == TRUE ~ trimws(gsub(pattern = "(.+)(Dispo)$", replacement = "\\1", x = Symbol, ignore.case = T), which = "both"),
-                             ProductType %in% c('Futures') && grepl(pattern = "(.)( )([0-9]{2})(/)([0-9]{2})( )([0-9]{2})(A)$", x = Ticker) == TRUE ~ trimws(gsub(pattern = "(.)( )([0-9]{2})(/)([0-9]{2})( )([0-9]{2})(A)$", replacement = "\\1", x = Symbol, ignore.case = T), which = "both"),
-                             ProductType %in% c('Futures') ~ trimws(gsub(pattern = "(.)?([[:alpha:]]{3})?([0-9]{2})?(/)?([0-9]{2})?( )?((A|M)||([0-9]){2})$", replacement = "\\1", x = Symbol, ignore.case = T), which = "both"),
-                             TRUE ~ NA_character_
-                             ),
-                           StrikePrice = case_when(
-                             ProductType %in% c('Options') && MarketSegmentId == 'MERV' ~ as.double(gsub(pattern = "(.{4})([0-9]+?\\.?[0-9]*)([[:alpha:]]+)", replacement = "\\2", x = Ticker, ignore.case = T)),
-                             ProductType %in% c('Options') && MarketSegmentId != 'MERV'~ as.double(gsub(pattern = "(.+)( )([0-9]+)([p|c])$", replacement = "\\3", x = Symbol, ignore.case = T)),
-                             TRUE ~ NA_real_
-                             )
-                           ) %>%
-                         select(Symbol, ProductType, MarketSegmentId, Ticker, OptionType, StrikePrice, Underlying, Settlement, MaturityDate, Cficode, everything()))
+    if (request %in% c('securities', 'by_type') && sec_detailed != FALSE) {
+      suppressWarnings(
+        data <- data %>%
+          mutate(
+            ProductType = factor(
+              gsub(
+                pattern = "(^.)(.+)",
+                replacement = "\\1",
+                x = Cficode
+                ),
+              levels = c("E", "D", "C", "R", "O", "F", "T", "M"),
+              labels = c("Equities", "Debt", "Collective Investment Vehicles", "Entitlements", "Options", "Futures", "Referencial Instruments", "Others")
+              ),
+            Settlement = case_when(
+              grepl(pattern = ".+ - (.+[hs|CI|D])$", x = Symbol) == TRUE ~ trimws(gsub(pattern = ".+ - (.+)$", replacement = "\\1", x = Symbol, ignore.case = T), which = "both"),
+              TRUE ~ NA_character_
+              ),
+            OptionType = factor(
+              gsub(
+                pattern = "(^.{2})(.+)",
+                replacement = "\\1",
+                x = Cficode
+                ),
+              levels = c("OC", "OP", "OM"),
+              labels = c("Call", "Put", "Others")
+              ),
+            Ticker = case_when(
+              ProductType %in% c('Equities', 'Debt', 'Options') ~ trimws(gsub(pattern = "(MERV - XMEV - )(.+)( - .+)", replacement = "\\2", x = Symbol, ignore.case = T), which = "both"),
+              ProductType %in% c('Entitlements') ~ trimws(gsub(pattern = "(MERV - XMEV - )(.+)", replacement = "\\2", x = Symbol, ignore.case = T), which = "both"),
+              ProductType %in% c('Others') ~ trimws(gsub(pattern = "(.+)( - )(.+)$", replacement = "\\3", x = Symbol, ignore.case = T), which = "both"),
+              TRUE ~ Symbol
+              ),
+            Underlying = case_when(
+              ProductType %in% c('Options') && MarketSegmentId == 'MERV' ~ trimws(gsub(pattern = "(.{3})(.+)", replacement = "\\1", x = Ticker, ignore.case = T), which = "both"),
+              ProductType %in% c('Options') && MarketSegmentId != 'MERV'~ trimws(gsub(pattern = "(.)?([[:alpha:]]{3})?([0-9]{2})?(/)?([0-9]{2})?( )([0-9]+)([p|c])$", replacement = "\\1", x = Symbol, ignore.case = T), which = "both"),
+              ProductType %in% c('Futures') && grepl(pattern = "(Dispo)$", x = Ticker) == TRUE ~ trimws(gsub(pattern = "(.+)(Dispo)$", replacement = "\\1", x = Symbol, ignore.case = T), which = "both"),
+              ProductType %in% c('Futures') && grepl(pattern = "(.)( )([0-9]{2})(/)([0-9]{2})( )([0-9]{2})(A)$", x = Ticker) == TRUE ~ trimws(gsub(pattern = "(.)( )([0-9]{2})(/)([0-9]{2})( )([0-9]{2})(A)$", replacement = "\\1", x = Symbol, ignore.case = T), which = "both"),
+              ProductType %in% c('Futures') ~ trimws(gsub(pattern = "(.)?([[:alpha:]]{3})?([0-9]{2})?(/)?([0-9]{2})?( )?((A|M)||([0-9]){2})$", replacement = "\\1", x = Symbol, ignore.case = T), which = "both"),
+              TRUE ~ NA_character_
+              ),
+            StrikePrice = case_when(
+              ProductType %in% c('Options') && MarketSegmentId == 'MERV' ~ as.double(gsub(pattern = "(.{4})([0-9]+?\\.?[0-9]*)([[:alpha:]]+)", replacement = "\\2", x = Ticker, ignore.case = T)),
+              ProductType %in% c('Options') && MarketSegmentId != 'MERV'~ as.double(gsub(pattern = "(.+)( )([0-9]+)([p|c])$", replacement = "\\3", x = Symbol, ignore.case = T)),
+              TRUE ~ NA_real_
+              )
+            ) %>%
+          select(Symbol, ProductType, MarketSegmentId, Ticker, OptionType, StrikePrice, Underlying, Settlement, MaturityDate, Cficode, everything())
+        )
       }
 
   }
